from typing import Literal

BoxShadow = Literal[
    'sm',
    '',
    'md',
    'lg',
    'xl',
    '2xl',
    'inner',
    'none',
]
